@@ -9,7 +9,7 @@ we may have a livepatch change in the contract, allowing livepatch to be
 enabled on xenial. However, during the upgrade we cannot install livepatch on
 the system because the running kernel version will not be updated until reboot.
 
-Pro client touches a flag file
+UA client touches a flag file
 /var/lib/ubuntu-advantage/marker-reboot-cmds-required to indicate this script
 should run at next boot to process any pending/unresovled config operations.
 """
@@ -18,10 +18,11 @@ import logging
 import os
 import sys
 
-from uaclient import config, contract, exceptions, lock, messages
+from uaclient import config, contract, lock, status
 from uaclient.cli import setup_logging
 from uaclient.entitlements.fips import FIPSEntitlement
-from uaclient.system import subp
+from uaclient.exceptions import LockHeldError, UserFacingError
+from uaclient.util import ProcessExecutionError, UrlError, subp
 
 # Retry sleep backoff algorithm if lock is held.
 # Lock may be held by auto-attach on systems with ubuntu-advantage-pro.
@@ -33,7 +34,7 @@ def run_command(cmd, cfg):
     try:
         out, _ = subp(cmd.split(), capture=True)
         logging.debug("Successfully executed cmd: {}".format(cmd))
-    except exceptions.ProcessExecutionError as exec_error:
+    except ProcessExecutionError as exec_error:
         msg = (
             "Failed running cmd: {}\n"
             "Return code: {}\n"
@@ -74,7 +75,7 @@ def fix_pro_pkg_holds(cfg):
                     )
                 try:
                     entitlement.install_packages(cleanup_on_failure=False)
-                except exceptions.UserFacingError as e:
+                except UserFacingError as e:
                     logging.error(e.msg)
                     logging.warning(
                         "Failed to install packages at boot: {}".format(
@@ -82,25 +83,22 @@ def fix_pro_pkg_holds(cfg):
                         )
                     )
                     sys.exit(1)
-                cfg.notice_file.remove(
-                    "", messages.FIPS_SYSTEM_REBOOT_REQUIRED.msg
-                )
-                cfg.notice_file.remove("", messages.FIPS_REBOOT_REQUIRED_MSG)
+                cfg.remove_notice("", status.MESSAGE_FIPS_REBOOT_REQUIRED)
 
 
 def refresh_contract(cfg):
     try:
         contract.request_updated_contract(cfg)
-    except exceptions.UrlError as exc:
+    except UrlError as exc:
         logging.exception(exc)
-        logging.warning(messages.REFRESH_CONTRACT_FAILURE)
+        logging.warning(status.MESSAGE_REFRESH_CONTRACT_FAILURE)
         sys.exit(1)
 
 
 def process_remaining_deltas(cfg):
     cmd = "/usr/bin/python3 /usr/lib/ubuntu-advantage/upgrade_lts_contract.py"
     run_command(cmd=cmd, cfg=cfg)
-    cfg.notice_file.remove("", messages.LIVEPATCH_LTS_REBOOT_REQUIRED)
+    cfg.remove_notice("", status.MESSAGE_LIVEPATCH_LTS_REBOOT_REQUIRED)
 
 
 def process_reboot_operations(cfg):
@@ -124,13 +122,13 @@ def process_reboot_operations(cfg):
             process_remaining_deltas(cfg)
 
             cfg.delete_cache_key("marker-reboot-cmds")
-            cfg.notice_file.remove("", messages.REBOOT_SCRIPT_FAILED)
+            cfg.remove_notice("", status.MESSAGE_REBOOT_SCRIPT_FAILED)
             logging.debug("Successfully ran all commands on reboot.")
         except Exception as e:
             msg = "Failed running commands on reboot."
             msg += str(e)
             logging.error(msg)
-            cfg.notice_file.add("", messages.REBOOT_SCRIPT_FAILED)
+            cfg.add_notice("", status.MESSAGE_REBOOT_SCRIPT_FAILED)
 
 
 def main(cfg):
@@ -147,12 +145,12 @@ def main(cfg):
             max_retries=MAX_RETRIES_ON_LOCK_HELD,
         ):
             process_reboot_operations(cfg=cfg)
-    except exceptions.LockHeldError as e:
+    except LockHeldError as e:
         logging.warning("Lock not released. %s", str(e.msg))
         sys.exit(1)
 
 
 if __name__ == "__main__":
-    cfg = config.UAConfig(root_mode=True)
+    cfg = config.UAConfig()
     setup_logging(logging.INFO, logging.DEBUG, log_file=cfg.log_file)
     main(cfg=cfg)
